@@ -1,8 +1,8 @@
 /*
     The Resynthesizer - A GIMP plug-in for resynthesizing textures
-    Copyright (C) 2000  Paul Francis Harrison
+    Copyright (C) 2000 2008  Paul Francis Harrison
     Copyright (C) 2002  Laurent Despeyroux
-    Copyright (C) 2002  David Rodrguez Garca
+    Copyright (C) 2002  David Rodríguez García
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-    Update gimp image while preview by David Rodrguez Garca  */
+
+ */
 
 #include <stdio.h>
 #include <unistd.h>
