@@ -60,10 +60,11 @@
 ) )
 
 (script-fu-register "script-fu-smart-enlarge"
-                    "<Image>/Script-Fu/Enhance/Smart enlarge..."
+                    "<Image>/Filters/Enhance/Smart enlarge..."
 		    "Enlarge image, invent high frequency components.
+
 Requires resynthesizer plug-in."
-		    "Paul Harrison (pfh@yoyo.cc.monash.edu.au)"
+		    "Paul Harrison (pfh@logarithmic.net)"
 		    "Paul Harrison"
 		    "27/7/2000"
 		    "RGB GRAY"
@@ -105,14 +106,14 @@ Requires resynthesizer plug-in."
 ) )
 
 (script-fu-register "script-fu-smart-sharpen"
-                    "<Image>/Script-Fu/Enhance/Smart sharpen..."
+                    "<Image>/Filters/Enhance/Smart sharpen..."
 		    "Sharpen image by inventing high frequency components.
 
 Requires resynthesizer plug-in."
 		    "Paul Harrison (pfh@logarithmic.net)"
 		    "Paul Harrison"
 		    "27/7/2000"
-		    "RGB GRAY"
+		    "RGB* GRAY*"
 		    SF-IMAGE "Input Image" 0
 		    SF-DRAWABLE "Input Layer" 0
 		    SF-ADJUSTMENT "Sharpening factor" '(2 1 32 0.1 1.0 2 1)
