@@ -67,7 +67,7 @@
 ) ) ))
 
 (script-fu-register "script-fu-smart-remove"
-                    "<Image>/Script-Fu/Enhance/Smart remove selection..."
+                    "<Image>/Filters/Enhance/Smart remove selection..."
 		    "Remove an object from an image by extending surrounding texture to cover it.
 
 Requires resynthesizer plug-in."
